@@ -2,7 +2,7 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
- * Copyright (C) 2024 Denis <denis@nzbget.com>
+ * Copyright (C) 2024-2025 Denis <denis@nzbget.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,33 @@ var Util = (new function($)
 {
 	'use strict';
 
+	this.emptyObject = function(obj) {
+		if (!obj) return true;
+		if (Object.keys(obj).length == 0) return true;
+		return false;
+	}
+
+	this.saveToLocalStorage = function(key, val)
+	{
+		try 
+		{
+			localStorage.setItem(key, val);
+		} catch (error) 
+		{
+			console.error(error);
+		}
+	}
+
+	this.getFromLocalStorage = function(key)
+	{
+		return localStorage.getItem(key);
+	}
+
+	this.removeFromLocalStorage = function(key)
+	{
+		return localStorage.removeItem(key);
+	}
+
 	this.formatTimeHMS = function(sec)
 	{
 		var hms = '';
@@ -83,8 +110,35 @@ var Util = (new function($)
 		return seconds + 's';
 	}
 
+	this.isNumber = function(value)
+	{
+		return typeof value === 'number';
+	}
+
+	this.getDaySinceUnixEpoch = function (date) 
+	{
+		var utcDate = new Date(Date.UTC(
+			date.getFullYear(),
+			date.getMonth(),
+			date.getDate()
+		));
+
+		// Get the number of milliseconds since the Unix epoch (UTC).
+		var utcTime = utcDate.getTime();
+
+		// Divide by the number of milliseconds in a day to get the number of days.
+		var daysSinceEpoch = Math.floor(utcTime / (1000 * 60 * 60 * 24));
+
+		return daysSinceEpoch;
+	}
+
 	this.formatDateTime = function(unixTime)
 	{
+		if (!Util.isNumber(unixTime) || unixTime < 0)
+		{
+			return '';
+		}
+
 		var dt = new Date(unixTime * 1000);
 		var h = dt.getHours();
 		var m = dt.getMinutes();
@@ -139,7 +193,7 @@ var Util = (new function($)
 
 	this.formatSpeed = function (bytesPerSec) 
 	{
-		if (bytesPerSec <= 0)
+		if (!Util.isNumber(bytesPerSec) || bytesPerSec < 0) 
 		{
 			return '';
 		}
@@ -172,6 +226,42 @@ var Util = (new function($)
 		return Util.round0(bytesPerSec / 1024.0) + ' KB/s';
 	}
 
+	this.formatNetworkSpeed = function(speedMbps) 
+	{
+		if (!Util.isNumber(speedMbps))
+		{
+			return '';
+		}
+
+		if (!speedMbps || speedMbps < 0)
+		{
+			return '';
+		}
+
+		if (speedMbps >= 10000) 
+		{
+			return Util.round1(speedMbps / 10000) + ' Gbps';
+		}
+		if (speedMbps >= 1000) 
+		{
+			return Util.round1(speedMbps / 1000) + ' Gbps';
+		} 
+		else if (speedMbps >= 100) 
+		{
+			return Util.round0(speedMbps) + ' Mbps';
+		} 
+		else if (speedMbps >= 10) 
+		{
+			return Util.round1(speedMbps) + ' Mbps';
+		} 
+		else if (speedMbps >= 1) 
+		{
+			return Util.round2(speedMbps) + ' Mbps';
+		}
+
+		return Util.round0(speedMbps * 1000) + ' Kbps';
+	}
+
 	this.formatSpeedWithCustomUnit = function (bytesPerSec, unit) 
 	{
 		var res = this.formatSpeed(bytesPerSec);
@@ -180,9 +270,9 @@ var Util = (new function($)
 
 	this.formatAge = function(time)
 	{
-		if (time == 0)
+		if (time <= 0)
 		{
-			return '';
+			return '--';
 		}
 
 		var diff = new Date().getTime() / 1000 - time;
@@ -194,12 +284,41 @@ var Util = (new function($)
 		{
 			return this.round0(diff / (60*60))  +'&nbsp;h';
 		}
+		else if (diff <= 0)
+		{
+			return '--';
+		}
 		else
 		{
 			return this.round0(diff / (60))  +'&nbsp;m';
 		}
 	}
 
+	this.formatNumber = function (num) 
+	{
+		var formattedNum;
+
+		if (num >= 1000000000) 
+		{
+			formattedNum = (num / 1000000000).toFixed(0);
+			return formattedNum + 'B';
+		}
+		else if (num >= 1000000) 
+		{
+			formattedNum = (num / 1000000).toFixed(0);
+			return formattedNum + 'M';
+		}
+		else if (num >= 1000) 
+		{
+			formattedNum = (num / 1000).toFixed(0);
+			return formattedNum + 'K';
+		}
+		else 
+		{
+			return num.toFixed(0);
+		}
+	}
+
 	this.round0 = function(arg)
 	{
 		return Math.round(arg);
